# figshare_get

Download a figshare article or collection using its DOI

## Installation

Install this Python package:

```bash
pip install figshare-get
```

## Usage

Find the DOI of the figshare article or collection - for example, click on the
"Cite" button on the figshare page and then "Copy DOI".

```bash
figshare_get 10.6084/m9.figshare.c.4081802.v1
```
